summaryrefslogtreecommitdiffstats
path: root/kmail/folderstorage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderstorage.cpp')
-rw-r--r--kmail/folderstorage.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/kmail/folderstorage.cpp b/kmail/folderstorage.cpp
index 6744e136..e1a7f364 100644
--- a/kmail/folderstorage.cpp
+++ b/kmail/folderstorage.cpp
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -113,7 +113,7 @@ void FolderStorage::close( const char* owner, bool aForced )
TQString FolderStorage::dotEscape(const TQString& aStr)
{
if (aStr[0] != '.') return aStr;
- return aStr.left(aStr.find(TQRegExp("[^\\.]"))) + aStr;
+ return aStr.left(aStr.tqfind(TQRegExp("[^\\.]"))) + aStr;
}
void FolderStorage::addJob( FolderJob* job ) const
@@ -174,7 +174,7 @@ void FolderStorage::markNewAsUnread()
if (!(msgBase = getMsgBase(i))) continue;
if (msgBase->isNew())
{
- msgBase->seStatus(KMMsgStatusUnread);
+ msgBase->setqStatus(KMMsgStatusUnread);
msgBase->setDirty(true);
}
}
@@ -301,9 +301,9 @@ void FolderStorage::emitMsgAddedSignals(int idx)
bool FolderStorage::canAddMsgNow(KMMessage* aMsg, int* aIndex_ret)
{
if (aIndex_ret) *aIndex_ret = -1;
- KMFolder *msgParent = aMsg->parent();
- // If the message has a parent and is in transfer, bail out. If it does not
- // have a parent we want to be able to add it even if it is in transfer.
+ KMFolder *msgParent = aMsg->tqparent();
+ // If the message has a tqparent and is in transfer, bail out. If it does not
+ // have a tqparent we want to be able to add it even if it is in transfer.
if (aMsg->transferInProgress() && msgParent)
return false;
if (!aMsg->isComplete() && msgParent && msgParent->folderType() == KMFolderTypeImap)
@@ -326,7 +326,7 @@ void FolderStorage::reallyAddMsg(KMMessage* aMsg)
return;
aMsg->setTransferInProgress( false );
aMsg->setComplete( true );
- KMFolder *aFolder = aMsg->parent();
+ KMFolder *aFolder = aMsg->tqparent();
int index;
ulong serNum = aMsg->getMsgSerNum();
bool undo = aMsg->enableUndo();
@@ -350,8 +350,8 @@ void FolderStorage::reallyAddCopyOfMsg(KMMessage* aMsg)
unGetMsg( count() - 1 );
}
-int FolderStorage::find( const KMMessage * msg ) const {
- return find( &msg->toMsgBase() );
+int FolderStorage::tqfind( const KMMessage * msg ) const {
+ return tqfind( &msg->toMsgBase() );
}
//-----------------------------------------------------------------------------
@@ -359,7 +359,7 @@ void FolderStorage::removeMsg(const TQPtrList<KMMsgBase>& msgList, bool imapQuie
{
for( TQPtrListIterator<KMMsgBase> it( msgList ); *it; ++it )
{
- int idx = find(it.current());
+ int idx = tqfind(it.current());
assert( idx != -1);
removeMsg(idx, imapQuiet);
}
@@ -370,7 +370,7 @@ void FolderStorage::removeMsg(const TQPtrList<KMMessage>& msgList, bool imapQuie
{
for( TQPtrListIterator<KMMessage> it( msgList ); *it; ++it )
{
- int idx = find(it.current());
+ int idx = tqfind(it.current());
assert( idx != -1);
removeMsg(idx, imapQuiet);
}
@@ -463,9 +463,9 @@ void FolderStorage::take(TQPtrList<KMMessage> msgList)
{
for ( KMMessage* msg = msgList.first(); msg; msg = msgList.next() )
{
- if (msg->parent())
+ if (msg->tqparent())
{
- int idx = msg->parent()->find(msg);
+ int idx = msg->tqparent()->tqfind(msg);
if ( idx >= 0 )
take(idx);
}
@@ -621,7 +621,7 @@ FolderJob* FolderStorage::createJob( TQPtrList<KMMessage>& msgList, const TQStri
int FolderStorage::moveMsg(KMMessage* aMsg, int* aIndex_ret)
{
assert(aMsg != 0);
- KMFolder* msgParent = aMsg->parent();
+ KMFolder* msgParent = aMsg->tqparent();
if (msgParent)
msgParent->open("moveMsgSrc");
@@ -641,7 +641,7 @@ int FolderStorage::moveMsg(TQPtrList<KMMessage> msglist, int* aIndex_ret)
{
KMMessage* aMsg = msglist.first();
assert(aMsg != 0);
- KMFolder* msgParent = aMsg->parent();
+ KMFolder* msgParent = aMsg->tqparent();
if (msgParent)
msgParent->open("foldermovemsg");
@@ -681,7 +681,7 @@ int FolderStorage::rename(const TQString& newName, KMFolderDir *newParent)
close("rename", true);
oldName = folder()->fileName();
- oldParent = folder()->parent();
+ oldParent = folder()->tqparent();
if (newParent)
folder()->setParent( newParent );
@@ -723,14 +723,14 @@ int FolderStorage::rename(const TQString& newName, KMFolderDir *newParent)
}
// if the folder is being moved then move its node and, if necessary, also
// the associated subfolder directory node to the new parent
if (newParent) {
if (oldParent->findRef( folder() ) != -1)
oldParent->take();
newParent->inSort( folder() );
if ( child ) {
- if ( child->parent()->findRef( child ) != -1 )
- child->parent()->take();
+ if ( child->tqparent()->findRef( child ) != -1 )
+ child->tqparent()->take();
newParent->inSort( child );
child->setParent( newParent );
}
@@ -861,18 +861,18 @@ bool FolderStorage::isCloseToQuota() const
}
//-----------------------------------------------------------------------------
-void FolderStorage::msgStatusChanged(const KMMsgStatus oldStatus,
- const KMMsgStatus newStatus, int idx)
+void FolderStorage::msgStatusChanged(const KMMsgtqStatus oldtqStatus,
+ const KMMsgtqStatus newtqStatus, int idx)
{
int oldUnread = 0;
int newUnread = 0;
- if (((oldStatus & KMMsgStatusUnread || oldStatus & KMMsgStatusNew) &&
- !(oldStatus & KMMsgStatusIgnored)) ||
+ if (((oldtqStatus & KMMsgStatusUnread || oldtqStatus & KMMsgStatusNew) &&
+ !(oldtqStatus & KMMsgStatusIgnored)) ||
(folder() == kmkernel->outboxFolder()))
oldUnread = 1;
- if (((newStatus & KMMsgStatusUnread || newStatus & KMMsgStatusNew) &&
- !(newStatus & KMMsgStatusIgnored)) ||
+ if (((newtqStatus & KMMsgStatusUnread || newtqStatus & KMMsgStatusNew) &&
+ !(newtqStatus & KMMsgStatusIgnored)) ||
(folder() == kmkernel->outboxFolder()))
newUnread = 1;
int deltaUnread = newUnread - oldUnread;
@@ -898,7 +898,7 @@ void FolderStorage::msgStatusChanged(const KMMsgStatus oldStatus,
void FolderStorage::headerOfMsgChanged(const KMMsgBase* aMsg, int idx)
{
if (idx < 0)
- idx = aMsg->parent()->find( aMsg );
+ idx = aMsg->tqparent()->tqfind( aMsg );
if (idx >= 0 )
{
@@ -1022,7 +1022,7 @@ int FolderStorage::appendToFolderIdsFile( int idx )
return ret;
}
-void FolderStorage::tqreplaceMsgSerNum( unsigned long sernum, KMMsgBase* msg, int idx )
+void FolderStorage::replaceMsgSerNum( unsigned long sernum, KMMsgBase* msg, int idx )
{
if ( !mExportsSernums ) return;
KMMsgDict::mutableInstance()->tqreplace( sernum, msg, idx );
@@ -1040,24 +1040,24 @@ void FolderStorage::setRDict( KMMsgDictREntry *rentry ) const
}
//-----------------------------------------------------------------------------
-void FolderStorage::seStatus(int idx, KMMsgStatus status, bool toggle)
+void FolderStorage::setqStatus(int idx, KMMsgtqStatus status, bool toggle)
{
KMMsgBase *msg = getMsgBase(idx);
if ( msg ) {
if (toggle)
- msg->toggleStatus(status, idx);
+ msg->toggletqStatus(status, idx);
else
- msg->seStatus(status, idx);
+ msg->setqStatus(status, idx);
}
}
//-----------------------------------------------------------------------------
-void FolderStorage::seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle)
+void FolderStorage::setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle)
{
for ( TQValueList<int>::Iterator it = ids.begin(); it != ids.end(); ++it )
{
- FolderStorage::seStatus(*it, status, toggle);
+ FolderStorage::setqStatus(*it, status, toggle);
}
}
@@ -1136,7 +1136,7 @@ void FolderStorage::slotProcessNextSearchBatch()
if ( !mSearchPattern )
return;
TQValueList<TQ_UINT32> matchingSerNums;
- const int end = QMIN( mCurrentSearchedMsg + 15, count() );
+ const int end = TQMIN( mCurrentSearchedMsg + 15, count() );
for ( int i = mCurrentSearchedMsg; i < end; ++i )
{
TQ_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), i );
@@ -723,14 +723,14 @@ int FolderStorage::rename(const TQString& newName, KMFolderDir *newParent)
}
// if the folder is being moved then move its node and, if necessary, also
- // the associated subfolder directory node to the new parent
+ // the associated subfolder directory node to the new tqparent
if (newParent) {
if (oldParent->findRef( folder() ) != -1)